==> eam-wshub-proxyclient-11.4-4-sources.jar: net/datastream/schemas/mp_fields/GISMAPPARAMETERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour GISMAPPARAMETERID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="GISMAPPARAMETERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GISMAPID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INSTALLATIONCODEID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "GISMAPPARAMETERID_Type", propOrder = {
    "gismapid",
    "installationcodeid"
})
public class GISMAPPARAMETERID_Type {

    @XmlElement(name = "GISMAPID", required = true)
    protected GISMAPID_Type gismapid;
    @XmlElement(name = "INSTALLATIONCODEID", required = true)
    protected INSTALLATIONCODEID_Type installationcodeid;

    /**
     * Obtient la valeur de la propriété gismapid.
     * 
     * @return
     *     possible object is
     *     {@link GISMAPID_Type }
     *     
     */
    public GISMAPID_Type getGISMAPID() {
        return gismapid;
    }

    /**
     * Définit la valeur de la propriété gismapid.
     * 
     * @param value
     *     allowed object is
     *     {@link GISMAPID_Type }
     *     
     */
    public void setGISMAPID(GISMAPID_Type value) {
        this.gismapid = value;
    }

    /**
     * Obtient la valeur de la propriété installationcodeid.
     * 
     * @return
     *     possible object is
     *     {@link INSTALLATIONCODEID_Type }
     *     
     */
    public INSTALLATIONCODEID_Type getINSTALLATIONCODEID() {
        return installationcodeid;
    }

    /**
     * Définit la valeur de la propriété installationcodeid.
     * 
     * @param value
     *     allowed object is
     *     {@link INSTALLATIONCODEID_Type }
     *     
     */
    public void setINSTALLATIONCODEID(INSTALLATIONCODEID_Type value) {
        this.installationcodeid = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/GISMAPPARAMETERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for GISMAPPARAMETERID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="GISMAPPARAMETERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GISMAPID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INSTALLATIONCODEID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "GISMAPPARAMETERID_Type", propOrder = {
    "gismapid",
    "installationcodeid"
})
public class GISMAPPARAMETERID_Type {

    @XmlElement(name = "GISMAPID", required = true)
    protected GISMAPID_Type gismapid;
    @XmlElement(name = "INSTALLATIONCODEID", required = true)
    protected INSTALLATIONCODEID_Type installationcodeid;

    /**
     * Gets the value of the gismapid property.
     * 
     * @return
     *     possible object is
     *     {@link GISMAPID_Type }
     *     
     */
    public GISMAPID_Type getGISMAPID() {
        return gismapid;
    }

    /**
     * Sets the value of the gismapid property.
     * 
     * @param value
     *     allowed object is
     *     {@link GISMAPID_Type }
     *     
     */
    public void setGISMAPID(GISMAPID_Type value) {
        this.gismapid = value;
    }

    /**
     * Gets the value of the installationcodeid property.
     * 
     * @return
     *     possible object is
     *     {@link INSTALLATIONCODEID_Type }
     *     
     */
    public INSTALLATIONCODEID_Type getINSTALLATIONCODEID() {
        return installationcodeid;
    }

    /**
     * Sets the value of the installationcodeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link INSTALLATIONCODEID_Type }
     *     
     */
    public void setINSTALLATIONCODEID(INSTALLATIONCODEID_Type value) {
        this.installationcodeid = value;
    }

}
